@@ -91,6 +91,9 @@ Tracer_dealloc(Tracer *self)
  static long get_memory_usage() {
     struct rusage r_usage;
     getrusage(RUSAGE_SELF,&r_usage);
+
+//    printf("%ld\n", r_usage.ru_maxrss);
+
     return r_usage.ru_maxrss;
  }
 
@@ -143,7 +146,7 @@ Tracer_dealloc(Tracer *self)
                  return RET_ERROR;
              }
 
-             if (self->total_mem_usage > 2000000) {
+             if (self->total_mem_usage > 2000) {
                  PyErr_SetString(PyExc_AssertionError, "Transaction exceeded memory usage!\n");
                  PyEval_SetTrace(NULL, NULL);
                  self->started = 0;
@@ -272,7 +275,7 @@ Tracer_methods[] = {
     { "get_stamp_used",  (PyCFunction) Tracer_get_stamp_used,     METH_VARARGS,
             PyDoc_STR("Get the stamp usage after it's been completed") },
 
-    { "get_locals_used",  (PyCFunction) Tracer_get_last_frame_mem_usage,     METH_VARARGS,
+    { "get_last_frame_mem_usage",  (PyCFunction) Tracer_get_last_frame_mem_usage,     METH_VARARGS,
             PyDoc_STR("Get the memory usage of the last Python frame processed.") },
 
     { "get_total_mem_usage",  (PyCFunction) Tracer_get_total_mem_usage,     METH_VARARGS,
