@@ -2,7 +2,7 @@ from unittest import TestCase
 from contracting.client import ContractingClient
 
 
-def module1():
+def con_module1():
     @export
     def get_context2():
         return {
@@ -14,7 +14,7 @@ def module1():
         }
 
 
-def all_in_one():
+def con_all_in_one():
     @export
     def call_me():
         return call_me_again()
@@ -34,10 +34,10 @@ def all_in_one():
         })
 
 
-def dynamic_import():
+def con_dynamic_import():
     @export
     def called_from_a_far():
-        m = importlib.import_module('all_in_one')
+        m = importlib.import_module('con_all_in_one')
         res = m.call_me_again_again()
 
         return [res, {
@@ -49,8 +49,8 @@ def dynamic_import():
         }]
 
     @export
-    def called_from_a_far_stacked():
-        m = importlib.import_module('all_in_one')
+    def con_called_from_a_far_stacked():
+        m = importlib.import_module('con_all_in_one')
         return m.call()
 
 
@@ -59,34 +59,34 @@ class TestRandomsContract(TestCase):
         self.c = ContractingClient(signer='stu')
         self.c.flush()
 
-        self.c.submit(module1)
+        self.c.submit(con_module1)
 
-        self.c.submit(all_in_one)
-        self.c.submit(dynamic_import)
+        self.c.submit(con_all_in_one)
+        self.c.submit(con_dynamic_import)
 
     def tearDown(self):
         self.c.flush()
 
     def test_ctx2(self):
-        module = self.c.get_contract('module1')
+        module = self.c.get_contract('con_module1')
         res = module.get_context2()
         expected = {
             'name': 'get_context2',
             'owner': None,
-            'this': 'module1',
+            'this': 'con_module1',
             'signer': 'stu',
             'caller': 'stu'
         }
         self.assertDictEqual(res, expected)
 
     def test_multi_call_doesnt_affect_parameters(self):
-        aio = self.c.get_contract('all_in_one')
+        aio = self.c.get_contract('con_all_in_one')
         res = aio.call_me()
 
         expected = {
             'name': 'call_me_again_again',
             'owner': None,
-            'this': 'all_in_one',
+            'this': 'con_all_in_one',
             'signer': 'stu',
             'caller': 'stu'
         }
@@ -94,21 +94,21 @@ class TestRandomsContract(TestCase):
         self.assertDictEqual(res, expected)
 
     def test_dynamic_call(self):
-        dy = self.c.get_contract('dynamic_import')
+        dy = self.c.get_contract('con_dynamic_import')
         res1, res2 = dy.called_from_a_far()
 
         expected1 = {
             'name': 'call_me_again_again',
             'owner': None,
-            'this': 'all_in_one',
+            'this': 'con_all_in_one',
             'signer': 'stu',
-            'caller': 'dynamic_import'
+            'caller': 'con_dynamic_import'
         }
 
         expected2 = {
             'name': 'called_from_a_far',
             'owner': None,
-            'this': 'dynamic_import',
+            'this': 'con_dynamic_import',
             'signer': 'stu',
             'caller': 'stu'
         }
