@@ -1,6 +1,5 @@
 from unittest import TestCase
 from contracting.db.encoder import encode, decode, safe_repr
-from decimal import Decimal as dec
 from contracting.stdlib.bridge.time import Datetime, Timedelta
 from datetime import datetime
 from contracting.stdlib.bridge.decimal import ContractingDecimal
@@ -38,8 +37,8 @@ class TestEncode(TestCase):
         self.assertEqual(decode(b), s)
 
     def test_decode_bytes_to_dec(self):
-        b = '0.0044997618965276'
-        d = dec('0.0044997618965276')
+        b = '{"__fixed__":"0.0044997618965276"}'
+        d = ContractingDecimal('0.0044997618965276')
 
         # _d is the actual Decimal object included in the wrapped stdlib ContractingDecimal
         self.assertEqual(decode(b)._d, d)
@@ -112,6 +111,18 @@ class TestEncode(TestCase):
 
     def test_contracting_decimal(self):
         c = ContractingDecimal(a=123.456)
-        b = '123.456'
+        b = '{"__fixed__":"123.456"}'
 
         self.assertEqual(encode(c), b)
+
+    def test_decode_fixed_trailing_doesnt_get_rid_of_zeros_properly(self):
+        b = '{"__fixed__":"1.10"}'
+
+        d = decode(b)
+
+    def test_encoding_fixed_trailing_zeros(self):
+        b = ContractingDecimal('123.000000')
+
+        e = encode(b)
+
+        print(e)
